@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.006013";
+    our $MITE_VERSION = "0.007000";
 
     BEGIN {
         require Scalar::Util;
@@ -240,9 +240,55 @@
             $self->{"required_methods"} = $value;
         };
 
+        # Attribute: method_signatures
+        do {
+            my $value =
+              exists( $args->{"method_signatures"} )
+              ? $args->{"method_signatures"}
+              : $self->_build_method_signatures;
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($v)
+                                  and $v->isa(q[Mite::Signature]);
+                            }
+                          );
+                    };
+                    for my $k ( keys %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( do { local $_ = $k; /\A[^\W0-9]\w*\z/ } )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "method_signatures", "Map[MethodName,Mite::Signature]";
+            $self->{"method_signatures"} = $value;
+        };
+
         # Enforce strict constructor
         my @unknown = grep not(
-/\A(?:attributes|imported_functions|name|r(?:equired_methods|oles)|s(?:him_name|ource))\z/
+/\A(?:attributes|imported_functions|method_signatures|name|r(?:equired_methods|oles)|s(?:him_name|ource))\z/
         ), keys %{$args};
         @unknown
           and croak(
@@ -346,6 +392,22 @@
         };
     }
 
+    # Accessors for method_signatures
+    if ($__XS) {
+        Class::XSAccessor->import(
+            chained   => 1,
+            "getters" => { "method_signatures" => "method_signatures" },
+        );
+    }
+    else {
+        *method_signatures = sub {
+            @_ > 1
+              ? croak(
+                "method_signatures is a read-only attribute of @{[ref $_[0]]}")
+              : $_[0]{"method_signatures"};
+        };
+    }
+
     # Accessors for name
     if ($__XS) {
         Class::XSAccessor->import(
